summaryrefslogtreecommitdiffstats
path: root/lib/kross
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2014-09-27 19:20:57 +0200
committerSlávek Banko <slavek.banko@axis.cz>2014-09-27 19:20:57 +0200
commit38518d610d1106fbca41bed7b3df4605958dc45d (patch)
tree2c4b0ff28f4ba8ccaac393ace70015305d9821dd /lib/kross
parent973ba55e2621b4db4644352bb699db2435ab5b29 (diff)
downloadkoffice-38518d610d1106fbca41bed7b3df4605958dc45d.tar.gz
koffice-38518d610d1106fbca41bed7b3df4605958dc45d.zip
Update for recent TDENewStuff changes
Diffstat (limited to 'lib/kross')
-rw-r--r--lib/kross/main/wdgscriptsmanager.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/kross/main/wdgscriptsmanager.cpp b/lib/kross/main/wdgscriptsmanager.cpp
index 18f19d68..7aea9b3a 100644
--- a/lib/kross/main/wdgscriptsmanager.cpp
+++ b/lib/kross/main/wdgscriptsmanager.cpp
@@ -36,16 +36,16 @@
#include <tdetoolbar.h>
#if KDE_IS_VERSION(3, 4, 0)
// The KNewStuffSecure we use internaly for the GetHotNewStuff-functionality
// was introduced with KDE 3.4.
#define KROSS_SUPPORT_NEWSTUFF
#endif
#ifdef KROSS_SUPPORT_NEWSTUFF
- #include <knewstuff/provider.h>
- #include <knewstuff/engine.h>
- #include <knewstuff/downloaddialog.h>
- #include <knewstuff/knewstuffsecure.h>
+ #include <tdenewstuff/provider.h>
+ #include <tdenewstuff/engine.h>
+ #include <tdenewstuff/downloaddialog.h>
+ #include <tdenewstuff/knewstuffsecure.h>
#endif
#include "scriptguiclient.h"
@@ -54,11 +54,11 @@
namespace Kross { namespace Api {
#ifdef KROSS_SUPPORT_NEWSTUFF
-class ScriptNewStuff : public KNewStuffSecure
+class ScriptNewStuff : public TDENewStuffSecure
{
public:
ScriptNewStuff(ScriptGUIClient* scripguiclient, const TQString& type, TQWidget *parentWidget = 0)
- : KNewStuffSecure(type, parentWidget)
+ : TDENewStuffSecure(type, parentWidget)
, m_scripguiclient(scripguiclient) {}
virtual ~ScriptNewStuff() {}
private:
@@ -321,7 +321,7 @@ void WdgScriptsManager::slotGetNewScript()
{
#ifdef KROSS_SUPPORT_NEWSTUFF
const TQString appname = TDEApplication::kApplication()->name();
- const TQString type = TQString("%1/script").arg(appname);
+ const TQString type = TQString("%1 1.x script").arg(appname);
if(! d->newstuff) {
d->newstuff = new ScriptNewStuff(d->m_scripguiclient, type);
@@ -336,17 +336,17 @@ void WdgScriptsManager::slotGetNewScript()
TQObject::connect(p, TQT_SIGNAL(providersLoaded(Provider::List*)),
d, TQT_SLOT(slotProviders(Provider::List*)));
- p->load(type, TQString("http://download.kde.org/khotnewstuff/%1scripts-providers.xml").arg(appname));
+ p->load(type, "https://www.trinitydesktop.org/ocs/providers.xml");
d->exec();
#endif
}
void WdgScriptsManager::slotResourceInstalled()
{
// Delete KNewStuff's configuration entries. These entries reflect what has
// already been installed. As we cannot yet keep them in sync after uninstalling
// scripts, we deactivate the check marks entirely.
- TDEGlobal::config()->deleteGroup("KNewStuffStatus");
+ TDEGlobal::config()->deleteGroup("TDENewStuffStatus");
}
}}
@@ -36,16 +36,16 @@
#include <tdetoolbar.h>
#if KDE_IS_VERSION(3, 4, 0)
- // The KNewStuffSecure we use internaly for the GetHotNewStuff-functionality
+ // The TDENewStuffSecure we use internaly for the GetHotNewStuff-functionality
// was introduced with KDE 3.4.
#define KROSS_SUPPORT_NEWSTUFF
@@ -336,17 +336,17 @@ void WdgScriptsManager::slotGetNewScript()
void WdgScriptsManager::slotResourceInstalled()
{
- // Delete KNewStuff's configuration entries. These entries reflect what has
+ // Delete TDENewStuff's configuration entries. These entries reflect what has
// already been installed. As we cannot yet keep them in sync after uninstalling
// scripts, we deactivate the check marks entirely.